'*************************************
'*  VGA 640 x 480 - RGBI-color bars  *
'*************************************
' made by Andy Schenk, Nov 2015

CON

  s = 44        'scales DAC output (s = 0..128)

  f_clock       = 80_000_000.0          'clock frequency
  f_scanline    = 31_250.0              'scanline frequency
  f_pixel       = f_scanline * 800.0    'pixel frequency for 800 pixels per scanline (25.0 MHz)
  f_xfr         = f_pixel / f_clock * float($7FFF_FFFF)


DAT             org

                setxfrq ##round(f_xfr)          'set transfer frequency

                setcy   mody                    'set colorspace converter coefficients
                setci   modi
                setcq   modq

		pinsetm	dacmode,#0		'enable dac modes in pins 0..3
		pinsetm	dacmode,#1
		pinsetm	dacmode,#2
		pinsetm	dacmode,#3

                setcmod #%01_0_0001             'set colorspace converter for VGA, neg HSync

                mov     x,#$FF                  'generate color bars in 256 bytes
                mov     ptra,##$1000
bars		wrbyte  x,ptra++
                djnz    x,#bars

                rdfast  #320/64,##$1000         'set rdfast to wrap on one line

		setb	dira,#0			'Vsync pin = output
		setb	outa,#0			'and high

'
'
' Field loop
'
field           mov     x,#33                   'top blanks
                call    #blank

                mov     x,#480                  'set visible lines
line            call    #sync                   'do horizontal sync
                xcont   m_rf,#0                 'visible line (rfbyte RGBI)
                djnz    x,#line                 'another line?

                mov     x,#10                   'bottom blanks
                call    #blank

                clrb    outa,#0                 'do vertical sync (negative)
                mov     x,#2
                call    #blank
                setb    outa,#0

                jmp     #field                  'field loop


blank           call    #sync                   'blank lines
                xcont   m_vi,#0
                djnz    x,#blank
                ret

sync            xcont   m_bs,#0                 'horizontal sync
                xcont   m_sn,#1
                xcont   m_bv,#0
		ret

'
'
' Initialized data
'
dacmode		long	%101<<29 + %10100<<8

mody            long    $01_00_00_00 * s        'red gain
modi            long    $00_01_00_00 * s        'green gain
modq            long    $00_00_01_00 * s        'blue gain

m_bs            long    $CF000000+16            'before sync
m_sn            long    $CF000000+96            'sync
m_bv            long    $CF000000+48            'before visible
m_vi            long    $CF000000+640           'visible

m_rf            long    $1F020000+640           'visible rfbyte RGBI

x               long    0
