'****************************************
'*  VGA 320 x 480 - characters colored  *
'****************************************
' made by Andy Schenk, Nov 2015

CON
  BOARD123	= 0			'0 = DE0 or DE2 boards

  s = 44 + BOARD123*36			'scales DAC output (s = 0..128)

  f_clock       = 80_000_000.0          'clock frequency
  f_scanline    = 31_250.0              'scanline frequency
  f_pixel       = f_scanline * 400.0    'pixel frequency for 400 pixels per scanline (25.0 MHz)
  f_xfr         = f_pixel / f_clock * float($7FFF_FFFF)

  VSYNC		= 0

DAT             org

                setxfrq ##round(f_xfr)          'set transfer frequency

                setcy   mody                    'set colorspace converter coefficients
                setci   modi
                setcq   modq

		pinsetm	dacmode,#0		'enable dac modes in pins 0..3
		pinsetm	dacmode,#1
		pinsetm	dacmode,#2
		pinsetm	dacmode,#3

                setcmod #%01_0_0001             'set colorspace converter for VGA, neg HSync

' Color palette
                wrlut   bg,#0                   'dark blue
                wrlut   ##$40_80_F0_00,#1       'light blue
                wrlut   bg,#32                  'dark blue
                wrlut   ##$C0_40_C0_00,#33      'light red
                wrlut   bg,#64                  'dark blue
                wrlut   ##$40_FF_40_00,#65      'light green
                wrlut   bg,#96                  'dark blue
                wrlut   ##$C0_C0_00_00,#97      'light yellw
'               wrlut   bg,#$80                 'dark blue
                wrlut   ##$80_80_80_00,#$80     'light gray
                wrlut   ##$40_40_40_00,#$81     'mid gray
                wrlut   bg,#$A0                 'dark blue
                wrlut   ##$30_B0_B0_00,#$A1     'light cyan
                wrlut   bg,#$C0                 'dark blue
                wrlut   ##$C0_80_40_00,#$C1     'light orange
                wrlut   bg,#$E0                 'dark blue
                wrlut   ##$FF_FF_FF_00,#$E1     'white
                ' 8 more color pairs possible here


                mov     ptra,##$1050            'demo chars and colors
                mov     x,#32
                mov     y,#511
demo            mov     t1,y
                shr     t1,#6
                shl     t1,#12
                or      t1,x
                wrword  t1,ptra++
                incmod  x,#127
                djnz    y,#demo


		setb	dira,#VSYNC		'Vsync pin = output
		setb	outa,#VSYNC		'and high

'
'
' Field loop
'
field           mov     x,#33                   'top blanks
                call    #blank

                mov     row,#0                  'row shift
                mov     y,#320                  'set visible lines (40 char lines)
                mov     scp,##$1000             'screen
line            mov     x,#40                   '40 chars per line
                call    #sync                   'do horizontal sync
                rdfast  #0,scp
                cmpr    row,#31  wc
chrs            rfword  t1                      'get char from screen
                getnib  t2,t1,#3
                setnib  m_rf,t2,#4              'set color 0..15
                rcl     t1,#1                   '2 font-longs per char
                alts    t1,#font
                mov     t1,0-0                  'read font-long
                shr     t1,row                  'shift row byte to byte0
                xcont   m_rf,t1                 '1 char row (imm 1bit LUT) 8 pixels
                djnz    x,#chrs                 'another char?
                add     row,#8                  'next row byte
                cmpsub  row,#64  wc
        if_c    add     scp,#80                 'next line of chars
	if_c	mov	x,#4
	if_c	call	#bgrnd
                djnz    y,#line                 'another line?

                mov     x,#10                   'bottom blanks
                call    #blank

                clrb    outa,#VSYNC             'do vertical sync (negative)
                mov     x,#2
                call    #blank
                setb    outa,#VSYNC

                jmp     #field                  'field loop


blank           call    #sync                   'blank lines
                xcont   m_vi,#0
                djnz    x,#blank
                ret

sync            xcont   m_bs,#0                 'horizontal sync
                xcont   m_sn,#1
                xcont   m_bv,#0
		ret

bgrnd           call    #sync                   'blank lines
                xcont   m_vb,#0
                djnz    x,#bgrnd
                ret

'
'
' Initialized data
'
dacmode		long	%101<<29 + %10100<<8

mody            long    $01_00_00_00 * s        'red gain
modi            long    $00_01_00_00 * s        'green gain
modq            long    $00_00_01_00 * s        'blue gain

m_bs            long    $CF000000+8             'before sync
m_sn            long    $CF000000+48            'sync
m_bv            long    $CF000000+24            'before visible
m_vi            long    $CF000000+320           'visible
m_vb            long    $8F000000+320           'visible

m_rf            long    $8F000000+8             'visible 1bit imm LUT

colset          long    $40000
bg              long    $10_10_30_00

x               long    0
y               long    0
row             long    0
scp             long    0
t1              long    0
t2              long    0


' FONT: 128 chars in 256 longs in cogram

font    byte  %00000000 ' ........    $00
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $01
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %11111000 ' #####...
        byte  %11111110 ' #######.
        byte  %00000110 ' .....##.
        byte  %00000011 ' ......##
        byte  %00000011 ' ......##
                         
        byte  %00000000 ' ........    $02
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00011111 ' ...#####
        byte  %01111111 ' .#######
        byte  %01100000 ' .##......
        byte  %11000000 ' ##......
        byte  %11000000 ' ##......
                         
        byte  %00000011 ' ......##    $03
        byte  %00000011 ' ......##
        byte  %00000110 ' .....##.
        byte  %11111100 ' ######..
        byte  %11111000 ' #####...
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
                         
        byte  %11000000 ' ##......    $04
        byte  %11000000 ' ##......
        byte  %01100000 ' .##.....
        byte  %00111111 ' ..######
        byte  %00011111 ' ...#####
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
                         
        byte  %00000011 ' ......##    $05
        byte  %00000011 ' ......##
        byte  %00000011 ' ......##
        byte  %00000011 ' ......##
        byte  %00000011 ' ......##
        byte  %00000011 ' ......##
        byte  %00000011 ' ......##
        byte  %00000011 ' ......##
                         
        byte  %11000000 ' ##......    $06
        byte  %11000000 ' ##......
        byte  %11000000 ' ##......
        byte  %11000000 ' ##......
        byte  %11000000 ' ##......
        byte  %11000000 ' ##......
        byte  %11000000 ' ##......
        byte  %11000000 ' ##......
                         
        byte  %00000000 ' ,,,,,,,,    $07
        byte  %00000000 ' ,,,,,,,,
        byte  %00000000 ' ,,,,,,,,
        byte  %11111111 ' ########
        byte  %11111111 ' ########
        byte  %00000000 ' ,,,,,,,,
        byte  %00000000 ' ,,,,,,,,
        byte  %00000000 ' ,,,,,,,,
                         
        byte  %00000000 ' ........    $08
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %11111111 ' ########
        byte  %11111111 ' ########
        byte  %00000011 ' ......##
        byte  %00000011 ' ......##
        byte  %00000011 ' ......##
                         
        byte  %00000000 ' ........    $09
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %11111111 ' ########
        byte  %11111111 ' ########
        byte  %11000000 ' ##......
        byte  %11000000 ' ##......
        byte  %11000000 ' ##......
                         
        byte  %00000011 ' ......##    $0A
        byte  %00000011 ' ......##
        byte  %00000011 ' ......##
        byte  %11111111 ' ########
        byte  %11111111 ' ########
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
                         
        byte  %11000000 ' ##......    $0B
        byte  %11000000 ' ##......
        byte  %11000000 ' ##......
        byte  %11111111 ' ########
        byte  %11111111 ' ########
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $0C
        byte  %11111111 ' ########
        byte  %11111111 ' ########
        byte  %00111100 ' ..####..
        byte  %00111100 ' ..####..
        byte  %00011000 ' ...##.,,
        byte  %00011000 ' ...##.,,
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $0C
        byte  %00011000 ' ...##.,,
        byte  %00011000 ' ...##.,,
        byte  %00111100 ' ..####..
        byte  %00111100 ' ..####..
        byte  %11111111 ' ########
        byte  %11111111 ' ########
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $0E
        byte  %11111111 ' ########
        byte  %10000001 ' #......#
        byte  %10000001 ' #......#
        byte  %10000001 ' #......#
        byte  %10000001 ' #......#
        byte  %11111111 ' ########
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $0F
        byte  %11111111 ' ########
        byte  %10000001 ' #......#
        byte  %10111101 ' #.####.#
        byte  %10111101 ' #.####.#
        byte  %10000001 ' #......#
        byte  %11111111 ' ########
        byte  %00000000 ' ........
                         
        byte  %11011011 ' ##.##.##    $10
        byte  %11011011 ' ##.##.##
        byte  %11011011 ' ##.##.##
        byte  %11011011 ' ##.##.##
        byte  %11011011 ' ##.##.##
        byte  %11011011 ' ##.##.##
        byte  %11011011 ' ##.##.##
        byte  %11011011 ' ##.##.##
                         
        byte  %11111111 ' ########    $11
        byte  %11111111 ' ########
        byte  %00000000 ' ........
        byte  %11111111 ' ########
        byte  %11111111 ' ########
        byte  %00000000 ' ........
        byte  %11111111 ' ########
        byte  %11111111 ' ########
                         
        byte  %00110010 ' .#..##..    $12
        byte  %10011001 ' #..##..#
        byte  %01001100 ' ..##..#.
        byte  %01100110 ' .##..##.
        byte  %00110011 ' ##..##..
        byte  %10011001 ' #..##..#
        byte  %01001100 ' ..##..#.
        byte  %01100110 ' .##..##.
                         
        byte  %00000000 ' ........    $13
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %11111111 ' ########
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $14
        byte  %11111111 ' ########
        byte  %11111111 ' ########
        byte  %11111111 ' ########
        byte  %11111111 ' ########
        byte  %11111111 ' ########
        byte  %11111111 ' ########
        byte  %00000000 ' ........
                         
                         
        byte  %00000000 ' ........    $15
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %11111000 ' ...#####
        byte  %11111000 ' ...#####
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
                         
        byte  %00000000 ' ........    $16
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %11111111 ' ########
        byte  %11111111 ' ########
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $17
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00011111 ' #####...
        byte  %00011111 ' #####...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
                         
        byte  %00011000 ' ...##...    $18
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %11111000 ' ...#####
        byte  %11111000 ' ...#####
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
                         
        byte  %00110000 ' ....##..    $19
        byte  %00110000 ' ....##..
        byte  %00110000 ' ....##..
        byte  %00111111 ' ######..
        byte  %00111111 ' ######..
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
                         
        byte  %00100000 ' .....#..    $1A
        byte  %00110000 ' ....##..
        byte  %00111000 ' ...###..
        byte  %00111100 ' ..####..
        byte  %00111000 ' ...###..
        byte  %00110000 ' ....##..
        byte  %00100000 ' .....#..
        byte  %00000000 ' ........
                         
                         
        byte  %00000100 ' ..#.....    $1B
        byte  %00001100 ' ..##....
        byte  %00011100 ' ..###...
        byte  %00111100 ' ..####..
        byte  %00011100 ' ..###...
        byte  %00001100 ' ..##....
        byte  %00000100 ' ..#.....
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $1C
        byte  %00011000 ' ...##...
        byte  %00111100 ' ..####..
        byte  %01111110 ' .######.
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $1D
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %01111110 ' .######.
        byte  %00111100 ' ..####..
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $1E
        byte  %00001000 ' ...#....
        byte  %00001100 ' ..##....
        byte  %01111110 ' .######.
        byte  %01111110 ' .######.
        byte  %00001100 ' ..##....
        byte  %00001000 ' ...#....
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $1F
        byte  %00010000 ' ....#...
        byte  %00110000 ' ....##..
        byte  %01111110 ' .######.
        byte  %01111110 ' .######.
        byte  %00110000 ' ....##..
        byte  %00010000 ' ....#...
        byte  %00000000 ' ........
                         
                         
        byte  %00000000 ' ........    $20  Space
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $21  !
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $22  "
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $23  #
        byte  %01100110 ' .##..##.
        byte  %11111111 ' ########
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %11111111 ' ########
        byte  %01100110 ' .##..##.
        byte  %00000000 ' ........
                         
        byte  %00011000 ' ...##...    $24  $
        byte  %01111100 ' ..#####.
        byte  %00000110 ' .##.....
        byte  %00111100 ' ..####..
        byte  %01100000 ' .....##.
        byte  %00111110 ' .#####..
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $25  %
        byte  %01100110 ' .##..##.
        byte  %00110110 ' .##.##..
        byte  %00011000 ' ...##...
        byte  %00001100 ' ..##....
        byte  %01100110 ' .##..##.
        byte  %01100010 ' .#...##.
        byte  %00000000 ' ........
                         
        byte  %00111000 ' ...###..    $26  &
        byte  %01101100 ' ..##.##.
        byte  %00111000 ' ...###..
        byte  %00011100 ' ..###...
        byte  %11110110 ' .##.####
        byte  %01100110 ' .##..##.
        byte  %11011100 ' ..###.##
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $27       '
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
                         
        byte  %01100000 ' .....##.    $28  (
        byte  %00110000 ' ....##..
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00110000 ' ....##..
        byte  %01100000 ' .....##.
                         
        byte  %00000110 ' .##.....    $29  )
        byte  %00001100 ' ..##....
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00001100 ' ..##....
        byte  %00000110 ' .##.....
                         
        byte  %00000000 ' ........    $2A  *
        byte  %01100110 ' .##..##.
        byte  %00111100 ' ..####..
        byte  %11111111 ' ########
        byte  %00111100 ' ..####..
        byte  %01100110 ' .##..##.
        byte  %00000000 ' ........
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $2B  +
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %01111110 ' .######.
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $2C  ,
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00001100 ' ..##....
                         
        byte  %00000000 ' ........    $2D  -
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %01111110 ' .######.
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $2E  .
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $2F  /
        byte  %01100000 ' .....##.
        byte  %00110000 ' ....##..
        byte  %00011000 ' ...##...
        byte  %00001100 ' ..##....
        byte  %00000110 ' .##.....
        byte  %00000010 ' .#......
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $30  0
        byte  %00111100 ' ..####..
        byte  %01100110 ' .##..##.
        byte  %01110110 ' .##.###.
        byte  %01101110 ' .###.##.
        byte  %01100110 ' .##..##.
        byte  %00111100 ' ..####..
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $31  1
        byte  %00011000 ' ...##...
        byte  %00011100 ' ..###...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %01111110 ' .######.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $32  2
        byte  %00111100 ' ..####..
        byte  %01100110 ' .##..##.
        byte  %00110000 ' ....##..
        byte  %00011000 ' ...##...
        byte  %00001100 ' ..##....
        byte  %01111110 ' .######.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $33  3
        byte  %01111110 ' .######.
        byte  %00110000 ' ....##..
        byte  %00011000 ' ...##...
        byte  %00110000 ' ....##..
        byte  %01100110 ' .##..##.
        byte  %00111100 ' ..####..
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $34  4
        byte  %00110000 ' ....##..
        byte  %00111000 ' ...###..
        byte  %00111100 ' ..####..
        byte  %00110110 ' .##.##..
        byte  %01111110 ' .######.
        byte  %00110000 ' ....##..
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $35  5
        byte  %01111110 ' .######.
        byte  %00000110 ' .##.....
        byte  %00111110 ' .#####..
        byte  %01100000 ' .....##.
        byte  %01100110 ' .##..##.
        byte  %00111100 ' ..####..
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $36  6
        byte  %00111100 ' ..####..
        byte  %00000110 ' .##.....
        byte  %00111110 ' .#####..
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00111100 ' ..####..
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $37  7
        byte  %01111110 ' .######.
        byte  %01100000 ' .....##.
        byte  %00110000 ' ....##..
        byte  %00011000 ' ...##...
        byte  %00001100 ' ..##....
        byte  %00001100 ' ..##....
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $38  8
        byte  %00111100 ' ..####..
        byte  %01100110 ' .##..##.
        byte  %00111100 ' ..####..
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00111100 ' ..####..
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $39  9
        byte  %00111100 ' ..####..
        byte  %01100110 ' .##..##.
        byte  %01111100 ' ..#####.
        byte  %01100000 ' .....##.
        byte  %00110000 ' ....##..
        byte  %00011100 ' ..###...
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $3A  :
        byte  %00000000 ' ........
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $3B  ;
        byte  %00000000 ' ........
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
        byte  %00011000 ' ...##...
        byte  %00001100 ' ..##....
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $3C  <
        byte  %00000000 ' ........
        byte  %01100000 ' .....##.
        byte  %00011000 ' ...##...
        byte  %00000110 ' .##.....
        byte  %00011000 ' ...##...
        byte  %01100000 ' .....##.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $3D  =
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %01111110 ' .######.
        byte  %00000000 ' ........
        byte  %01111110 ' .######.
        byte  %00000000 ' ........
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $3E  >
        byte  %00000000 ' ........
        byte  %00000110 ' .##.....
        byte  %00011000 ' ...##...
        byte  %01100000 ' .....##.
        byte  %00011000 ' ...##...
        byte  %00000110 ' .##.....
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $3F  ?
        byte  %00111100 ' ..####..
        byte  %01100110 ' .##..##.
        byte  %00110000 ' ....##..
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $40  @
        byte  %00111100 ' ..####..
        byte  %01100110 ' .##..##.
        byte  %01110110 ' .##.###.
        byte  %01110110 ' .##.###.
        byte  %00000110 ' .##.....
        byte  %01111100 ' ..#####.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $41  A
        byte  %00011000 ' ...##...
        byte  %00111100 ' ..####..
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01111110 ' .######.
        byte  %01100110 ' .##..##.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $42  B
        byte  %00111110 ' .#####..
        byte  %01100110 ' .##..##.
        byte  %00111110 ' .#####..
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00111110 ' .#####..
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $43  C
        byte  %00111100 ' ..####..
        byte  %01100110 ' .##..##.
        byte  %00000110 ' .##.....
        byte  %00000110 ' .##.....
        byte  %01100110 ' .##..##.
        byte  %00111100 ' ..####..
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $44  D
        byte  %00011110 ' .####...
        byte  %00110110 ' .##.##..
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00110110 ' .##.##..
        byte  %00011110 ' .####...
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $45  E
        byte  %01111110 ' .######.
        byte  %00000110 ' .##.....
        byte  %00111110 ' .#####..
        byte  %00000110 ' .##.....
        byte  %00000110 ' .##.....
        byte  %01111110 ' .######.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $46  F
        byte  %01111110 ' .######.
        byte  %00000110 ' .##.....
        byte  %00111110 ' .#####..
        byte  %00000110 ' .##.....
        byte  %00000110 ' .##.....
        byte  %00000110 ' .##.....
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $47  G
        byte  %01111100 ' ..#####.
        byte  %00000110 ' .##.....
        byte  %00000110 ' .##.....
        byte  %01110110 ' .##.###.
        byte  %01100110 ' .##..##.
        byte  %01111100 ' ..#####.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $48  H
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01111110 ' .######.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $49  I
        byte  %01111110 ' .######.
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %01111110 ' .######.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $4A  J
        byte  %01100000 ' .....##.
        byte  %01100000 ' .....##.
        byte  %01100000 ' .....##.
        byte  %01100000 ' .....##.
        byte  %01100110 ' .##..##.
        byte  %00111100 ' ..####..
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $4B  K
        byte  %01100110 ' .##..##.
        byte  %00110110 ' .##.##..
        byte  %00011110 ' .####...
        byte  %00011110 ' .####...
        byte  %00110110 ' .##.##..
        byte  %01100110 ' .##..##.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $4C  L
        byte  %00000110 ' .##.....
        byte  %00000110 ' .##.....
        byte  %00000110 ' .##.....
        byte  %00000110 ' .##.....
        byte  %00000110 ' .##.....
        byte  %01111110 ' .######.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $4D  M
        byte  %11000110 ' .##...##
        byte  %11101110 ' .###.###
        byte  %11111110 ' .#######
        byte  %11010110 ' .##.#.##
        byte  %11000110 ' .##...##
        byte  %11000110 ' .##...##
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $4E  N
        byte  %01100110 ' .##..##.
        byte  %01101110 ' .###.##.
        byte  %01111110 ' .######.
        byte  %01111110 ' .######.
        byte  %01110110 ' .##.###.
        byte  %01100110 ' .##..##.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $4F  O
        byte  %00111100 ' ..####..
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00111100 ' ..####..
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $50  P
        byte  %00111110 ' .#####..
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00111110 ' .#####..
        byte  %00000110 ' .##.....
        byte  %00000110 ' .##.....
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $51  Q
        byte  %00111100 ' ..####..
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00110110 ' .##.##..
        byte  %01101100 ' ..##.##.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $52  R
        byte  %00111110 ' .#####..
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00111110 ' .#####..
        byte  %00110110 ' .##.##..
        byte  %01100110 ' .##..##.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $53  S
        byte  %00111100 ' ..####..
        byte  %00000110 ' .##.....
        byte  %00111100 ' ..####..
        byte  %01100000 ' .....##.
        byte  %01100000 ' .....##.
        byte  %00111100 ' ..####..
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $54  T
        byte  %01111110 ' .######.
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $55  U
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00111100 ' ..####..
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $56  V
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00111100 ' ..####..
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $57  W
        byte  %11000110 ' .##...##
        byte  %11000110 ' .##...##
        byte  %11010110 ' .##.#.##
        byte  %11111110 ' .#######
        byte  %11101110 ' .###.###
        byte  %11000110 ' .##...##
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $58  X
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00111100 ' ..####..
        byte  %00111100 ' ..####..
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $59  Y
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00111100 ' ..####..
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $5A  Z
        byte  %01111110 ' .######.
        byte  %00110000 ' ....##..
        byte  %00011000 ' ...##...
        byte  %00001100 ' ..##....
        byte  %00000110 ' .##.....
        byte  %01111110 ' .######.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $5B  [
        byte  %01111000 ' ...####.
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %01111000 ' ...####.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $5C  \
        byte  %00000010 ' .#......
        byte  %00000110 ' .##.....
        byte  %00001100 ' ..##....
        byte  %00011000 ' ...##...
        byte  %00110000 ' ....##..
        byte  %01100000 ' .....##.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $5D  ]
        byte  %00011110 ' .####...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011110 ' .####...
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $5E  ^
        byte  %00010000 ' ....#...
        byte  %00111000 ' ...###..
        byte  %01101100 ' ..##.##.
        byte  %11000110 ' .##...##
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $5F  _
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %01111110 ' .######.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $60  `
        byte  %10000000 ' .......#
        byte  %11000000 ' ......##
        byte  %01100000 ' .....##.
        byte  %00110011 ' ##..##..
        byte  %00011110 ' .####...
        byte  %00001100 ' ..##....
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $61  a
        byte  %00000000 ' ........
        byte  %00111100 ' ..####..
        byte  %01100000 ' .....##.
        byte  %01111100 ' ..#####.
        byte  %01100110 ' .##..##.
        byte  %01111100 ' ..#####.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $62  b
        byte  %00000110 ' .##.....
        byte  %00000110 ' .##.....
        byte  %00111110 ' .#####..
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00111110 ' .#####..
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $63  c
        byte  %00000000 ' ........
        byte  %00111100 ' ..####..
        byte  %00000110 ' .##.....
        byte  %00000110 ' .##.....
        byte  %00000110 ' .##.....
        byte  %00111100 ' ..####..
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $64  d
        byte  %01100000 ' .....##.
        byte  %01100000 ' .....##.
        byte  %01111100 ' ..#####.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01111100 ' ..#####.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $65  e
        byte  %00000000 ' ........
        byte  %00111100 ' ..####..
        byte  %01100110 ' .##..##.
        byte  %01111110 ' .######.
        byte  %00000110 ' .##.....
        byte  %00111100 ' ..####..
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $66  f
        byte  %01110000 ' ....###.
        byte  %00011000 ' ...##...
        byte  %01111100 ' ..#####.
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $67  g
        byte  %00000000 ' ........
        byte  %01111100 ' ..#####.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01111100 ' ..#####.
        byte  %01100000 ' .....##.
        byte  %00111110 ' .#####..
                         
        byte  %00000000 ' ........    $68  h
        byte  %00000110 ' .##.....
        byte  %00000110 ' .##.....
        byte  %00111110 ' .#####..
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $69  i
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
        byte  %00011100 ' ..###...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00111100 ' ..####..
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $6A  j
        byte  %00110000 ' ....##..
        byte  %00000000 ' ........
        byte  %00110000 ' ....##..
        byte  %00110000 ' ....##..
        byte  %00110000 ' ....##..
        byte  %00110000 ' ....##..
        byte  %00011110 ' .####...
                         
        byte  %00000000 ' ........    $6B  k
        byte  %00000110 ' .##.....
        byte  %00000110 ' .##.....
        byte  %00110110 ' .##.##..
        byte  %00011110 ' .####...
        byte  %00110110 ' .##.##..
        byte  %01100110 ' .##..##.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $6C  l
        byte  %00011100 ' ..###...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00111100 ' ..####..
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $6D  m
        byte  %00000000 ' ........
        byte  %01100110 ' .##..##.
        byte  %11111110 ' .#######
        byte  %11111110 ' .#######
        byte  %11010110 ' .##.#.##
        byte  %11000110 ' .##...##
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $6E  n
        byte  %00000000 ' ........
        byte  %00111110 ' .#####..
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $6F  o
        byte  %00000000 ' ........
        byte  %00111100 ' ..####..
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00111100 ' ..####..
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $70  p
        byte  %00000000 ' ........
        byte  %00111110 ' .#####..
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00111110 ' .#####..
        byte  %00000110 ' .##.....
        byte  %00000110 ' .##.....
                         
        byte  %00000000 ' ........    $71  q
        byte  %00000000 ' ........
        byte  %01111100 ' ..#####.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01111100 ' ..#####.
        byte  %01100000 ' .....##.
        byte  %01100000 ' .....##.
                         
        byte  %00000000 ' ........    $72  r
        byte  %00000000 ' ........
        byte  %00111110 ' .#####..
        byte  %01100110 ' .##..##.
        byte  %00000110 ' .##.....
        byte  %00000110 ' .##.....
        byte  %00000110 ' .##.....
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $73  s
        byte  %00000000 ' ........
        byte  %01111100 ' ..#####.
        byte  %00000110 ' .##.....
        byte  %00111100 ' ..####..
        byte  %01100000 ' .....##.
        byte  %00111110 ' .#####..
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $74  t
        byte  %00011000 ' ...##...
        byte  %01111110 ' .######.
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %01110000 ' ....###.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $75  u
        byte  %00000000 ' ........
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01111100 ' ..#####.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $76  v
        byte  %00000000 ' ........
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %00111100 ' ..####..
        byte  %00011000 ' ...##...
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $77  w
        byte  %00000000 ' ........
        byte  %11000110 ' .##...##
        byte  %11010110 ' .##.#.##
        byte  %11111110 ' .#######
        byte  %01111100 ' ..#####.
        byte  %01101100 ' ..##.##.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $78  x
        byte  %00000000 ' ........
        byte  %01100110 ' .##..##.
        byte  %00111100 ' ..####..
        byte  %00011000 ' ...##...
        byte  %00111100 ' ..####..
        byte  %01100110 ' .##..##.
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $79  y
        byte  %00000000 ' ........
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01100110 ' .##..##.
        byte  %01111100 ' ..#####.
        byte  %00110000 ' ....##..
        byte  %00011110 ' .####...
                         
        byte  %00000000 ' ........    $7A  z
        byte  %00000000 ' ........
        byte  %01111110 ' .######.
        byte  %00110000 ' ....##..
        byte  %00011000 ' ...##...
        byte  %00001100 ' ..##....
        byte  %01111110 ' .######.
        byte  %00000000 ' ........
                         
        byte  %01100000 ' .....##.    $7B  {
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00000110 ' .##.....
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %01100000 ' .....##.
        byte  %00000000 ' ........
                         
        byte  %00011000 ' ...##...    $7C  |
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
                         
        byte  %00000110 ' .##.....    $7D  }
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %01100000 ' .....##.
        byte  %00011000 ' ...##...
        byte  %00011000 ' ...##...
        byte  %00000110 ' .##.....
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $7E  ~
        byte  %11001100 ' ..##..##
        byte  %01111110 ' .######.
        byte  %00110011 ' ##..##..
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
                         
        byte  %00000000 ' ........    $7F
        byte  %00011100 ' ..###...
        byte  %00100010 ' .#...#..
        byte  %00100010 ' .#...#..
        byte  %00011100 ' ..###...
        byte  %00000000 ' ........
        byte  %00000000 ' ........
        byte  %00000000 ' ........
' define your own characters here ($80..$BF)


                orgh    $1000
screen          word    "40 Chars per Line"
